@@ -31,6 +31,8 @@ import requests
 # are processed.
 #
 # This is supported in Python 3.7+
+from .models.table_monitoring import MonitoringResultPartial, MonitoringResult
+
 if typing.TYPE_CHECKING:
     import pandas
     import pyspark.sql
@@ -67,7 +69,7 @@ from .models.feature_store_run import FeatureStoreRun
 from .models.feature_template import FeatureTemplate, TemplateId, TemplateName
 from .models.feature_template_creation_request import FeatureTemplateCreationRequest
 from .models.file_format import CSV, FileFormat, Parquet, Orc
-from .models.jobs import RunStatus, FeatureStoreRunId
+from .models.jobs import RunStatus, FeatureStoreRunId, TableMonitoringRunId
 from .models.merge_request import MergeRequest, MergeRequestCreationRequest, MergeRequestId
 from .models.ref import Ref
 from .models.table import Table, TableId, TableName
@@ -394,6 +396,26 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return GeneratedFeatures.from_json(result)
 
+    def get_online_features_with_id(
+        self,
+        name,
+        feature_store_id: Union[FeatureStoreId, int],
+        primary_key
+    ) -> GeneratedFeatures:
+        """Get the features generated from a feature store for a particular primary key value.
+
+        Args:
+            name: Name of the destination online feature store table.
+            feature_store_id: Id of the feature store.
+            primary_key: Primary key of the entity to get.
+
+        Returns:
+            The features for the given primary key in the named feature store.
+        """
+        r = self._get(f"/online-store/{int(feature_store_id)}" + "/" + str(name) + "/" + str(primary_key))
+        result = self._json_or_handle_errors(r)
+        return GeneratedFeatures.from_json(result)
+
     def create_feature(self, feature: FeatureCreationRequest) -> Feature:
         """Create a feature definition on the Anaml server.
 
@@ -1036,6 +1058,69 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return Source.from_json(result)
 
+    # Table Monitoring Functions
+    def get_table_monitoring_result(
+        self,
+        run_id: Union[TableMonitoringRunId, int],
+        table_name: Optional[Union[TableName, str]] = None,
+        table_id: Optional[Union[TableId, int]] = None
+    ) -> List[MonitoringResultPartial]:
+        """Gets a monitoring result for a given run_id.
+
+        Optionally, a table_name / table_id can be supplied to get a specific table's results for that run_id
+
+        Args:
+            run_id: run_id of the requested job run
+            table_name [optional]: table_name in the requested job run
+            table_id [optional]: table_id in the requested job run
+
+        Returns:
+            The PARTIAL monitoring result for a given run_id -> MonitoringResultPartial
+
+            If a table name / id is supplied, the result will be for that table only.
+        """
+        if table_name:
+            table_id = self.get_table_by_name(table_name).id.value
+
+        if table_id:
+            r = self._get(f"/table-monitoring/table/{int(table_id)}/results")
+        else:
+            r = self._get(f"/table-monitoring/run/{int(run_id)}/results")
+
+        result = self._json_or_handle_errors(r)
+
+        return [MonitoringResultPartial.from_json(r) for r in result]
+
+    def get_latest_table_monitoring_result_by_table_name(
+        self,
+        table_name: Union[TableName, str],
+        full_results: Optional[bool] = False
+    ) -> Union[MonitoringResultPartial, MonitoringResult]:
+        """Gets the latest monitoring result for a specified table name.
+
+        Args:
+            name: Name of the table
+
+        Returns:
+            Default:
+                The PARTIAL monitoring result -> MonitoringResultPartial
+            If full_result=True:
+                The full monitoring result -> MonitoringResult
+        """
+        table_id = self.get_table_by_name(table_name).id.value
+
+        r = self._get(f"/table-monitoring/table/{int(table_id)}/results")
+        results = self._json_or_handle_errors(r)
+
+        latest_result_id = results[0]['id']
+        r = self._get(f"/table-monitoring/results/{int(latest_result_id)}")
+        latest_result = self._json_or_handle_errors(r)
+
+        if full_results:
+            return MonitoringResult.from_json(latest_result)
+        else:
+            return MonitoringResultPartial.from_json(latest_result)
+
     # Builder functions
     def build_event_feature(
         self,
